==> eea.soer-1.15.zip: eea.soer-1.15/eea/soer/browser/admin.py <==
""" Admin module for browser package
"""
from zope.interface import implements, Interface
from Products.CMFCore.utils import getToolByName
from Products.Five import BrowserView
from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
#from eea.soer import vocab

class IAdminView(Interface):
    """ IAdminView interface """

    def info():
        """ return countries and it's reports """


class AdminView(BrowserView):
    """ AdminView BrowserView
    """
    implements(IAdminView)

    def __init__(self, context, request):
        self.context = context
        self.request = request

    def info(self):
        """ info """
        #ret = []
        catalog = getToolByName(self.context, 'portal_catalog')
        countries = catalog(portal_type='SOERCountry')
        result = {'unknown' : { 'title': 'Unknown',
                                'url' : '',
                                'id' : '',
                                'common' : {'reports':[],
                                            'stats': {}},
                                'profile' : {'reports' : [],
                                             'stats' : 0}}
                 }
        for country in countries:
            result[country.getId] = { 'title': country.Title,
                                      'url' : country.getURL(),
                                      'id' : country.getId,
                                      'common' : {'reports':[],
                                                  'stats': {}},
                                      'profile' : {'reports' : [],
                                                   'stats' : 0 }}
            countryIds = result.keys()
        reports = catalog(portal_type=['DiversityReport', 'CommonalityReport'],
                          sort_on='sortable_title',
                          isSubReport=False)
        for brain in reports:
            obj = brain.getObject()
            country = 'unknown'
            if obj.getSoerCountry() in countryIds:
                country = obj.getSoerCountry()
            #handle special cases where gb & montenegro got renamed folder ids
            elif obj.getSoerCountry() == 'gb':
                country = 'uk'
            elif obj.getSoerCountry() == 'montenegro':
                country = 'me'
            country = result[country]
            if obj.portal_type == 'CommonalityReport':
                country['common']['reports'].append(brain)
                noQuestions =  country['common']['stats'].get(
                                                    obj.getTopic(), 0) + 1
                country['common']['stats'][obj.getTopic()] = noQuestions
            else:
                country['profile']['reports'].append(brain)
                country['profile']['stats'] += 1
        
        return [ c for _unused, c in result.items()]

    __call__ = ViewPageTemplateFile('admin.pt')

==> eea.soer-1.19.zip: eea.soer-1.19/eea/soer/browser/admin.py <==
""" Admin module for browser package
"""
from zope.interface import implements, Interface
from Products.CMFCore.utils import getToolByName
from Products.Five import BrowserView
from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
#from eea.soer import vocab

class IAdminView(Interface):
    """ IAdminView interface """

    def info(): #pyflakes, #pylint: disable-msg = E0211
        """ return countries and it's reports """


class AdminView(BrowserView):
    """ AdminView BrowserView
    """
    implements(IAdminView)

    def __init__(self, context, request): #pyflakes, #pylint: disable-msg = W0231
        self.context = context
        self.request = request

    def info(self):
        """ info """
        #ret = []
        catalog = getToolByName(self.context, 'portal_catalog')
        countries = catalog(portal_type='SOERCountry')
        result = {'unknown' : { 'title': 'Unknown',
                                'url' : '',
                                'id' : '',
                                'common' : {'reports':[],
                                            'stats': {}},
                                'profile' : {'reports' : [],
                                             'stats' : 0}}
                 }
        for country in countries:
            result[country.getId] = { 'title': country.Title,
                                      'url' : country.getURL(),
                                      'id' : country.getId,
                                      'common' : {'reports':[],
                                                  'stats': {}},
                                      'profile' : {'reports' : [],
                                                   'stats' : 0 }}
            countryIds = result.keys()
        reports = catalog(portal_type=['DiversityReport', 'CommonalityReport'],
                          sort_on='sortable_title',
                          isSubReport=False)
        for brain in reports:
            obj = brain.getObject()
            country = 'unknown'
            if obj.getSoerCountry() in countryIds:
                country = obj.getSoerCountry()
            #handle special cases where gb & montenegro got renamed folder ids
            elif obj.getSoerCountry() == 'gb':
                country = 'uk'
            elif obj.getSoerCountry() == 'montenegro':
                country = 'me'
            country = result[country]
            if obj.portal_type == 'CommonalityReport':
                country['common']['reports'].append(brain)
                noQuestions =  country['common']['stats'].get(
                                                    obj.getTopic(), 0) + 1
                country['common']['stats'][obj.getTopic()] = noQuestions
            else:
                country['profile']['reports'].append(brain)
                country['profile']['stats'] += 1
        
        return [ c for _unused, c in result.items()]

    __call__ = ViewPageTemplateFile('admin.pt')
